==> _private_core_network-0.0.63.tar.gz: lib/network_resources/model/the_movie_photo.dart <==
class TheMovieImage {
  List<TheMovieImageBackdrops>? backdrops;
  int? id;
  List<TheMovieImageLogos>? logos;
  List<TheMovieImagePosters>? posters;

  TheMovieImage({this.backdrops, this.id, this.logos, this.posters});

  TheMovieImage.fromJson(Map<String, dynamic> json) {
    backdrops = json["backdrops"] == null
        ? null
        : (json["backdrops"] as List)
            .map((e) => TheMovieImageBackdrops.fromJson(e))
            .toList();
    id = json["id"];
    logos = json["logos"] == null
        ? null
        : (json["logos"] as List)
            .map((e) => TheMovieImageLogos.fromJson(e))
            .toList();
    posters = json["posters"] == null
        ? null
        : (json["posters"] as List)
            .map((e) => TheMovieImagePosters.fromJson(e))
            .toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    if (backdrops != null) {
      _data["backdrops"] = backdrops?.map((e) => e.toJson()).toList();
    }
    _data["id"] = id;
    if (logos != null) {
      _data["logos"] = logos?.map((e) => e.toJson()).toList();
    }
    if (posters != null) {
      _data["posters"] = posters?.map((e) => e.toJson()).toList();
    }
    return _data;
  }

  TheMovieImage copyWith({
    List<TheMovieImageBackdrops>? backdrops,
    int? id,
    List<TheMovieImageLogos>? logos,
    List<TheMovieImagePosters>? posters,
  }) =>
      TheMovieImage(
        backdrops: backdrops ?? this.backdrops,
        id: id ?? this.id,
        logos: logos ?? this.logos,
        posters: posters ?? this.posters,
      );
}

class TheMovieImagePosters {
  num? aspectRatio;
  int? height;
  String? iso6391;
  String? filePath;
  num? voteAverage;
  int? voteCount;
  int? width;

  TheMovieImagePosters(
      {this.aspectRatio,
      this.height,
      this.iso6391,
      this.filePath,
      this.voteAverage,
      this.voteCount,
      this.width});

  TheMovieImagePosters.fromJson(Map<String, dynamic> json) {
    aspectRatio = json["aspect_ratio"];
    height = json["height"];
    iso6391 = json["iso_639_1"];
    filePath = json["file_path"];
    voteAverage = json["vote_average"];
    voteCount = json["vote_count"];
    width = json["width"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["aspect_ratio"] = aspectRatio;
    _data["height"] = height;
    _data["iso_639_1"] = iso6391;
    _data["file_path"] = filePath;
    _data["vote_average"] = voteAverage;
    _data["vote_count"] = voteCount;
    _data["width"] = width;
    return _data;
  }

  TheMovieImagePosters copyWith({
    num? aspectRatio,
    int? height,
    String? iso6391,
    String? filePath,
    num? voteAverage,
    int? voteCount,
    int? width,
  }) =>
      TheMovieImagePosters(
        aspectRatio: aspectRatio ?? this.aspectRatio,
        height: height ?? this.height,
        iso6391: iso6391 ?? this.iso6391,
        filePath: filePath ?? this.filePath,
        voteAverage: voteAverage ?? this.voteAverage,
        voteCount: voteCount ?? this.voteCount,
        width: width ?? this.width,
      );
}

class TheMovieImageLogos {
  num? aspectRatio;
  int? height;
  String? iso6391;
  String? filePath;
  num? voteAverage;
  int? voteCount;
  int? width;

  TheMovieImageLogos(
      {this.aspectRatio,
      this.height,
      this.iso6391,
      this.filePath,
      this.voteAverage,
      this.voteCount,
      this.width});

  TheMovieImageLogos.fromJson(Map<String, dynamic> json) {
    aspectRatio = json["aspect_ratio"];
    height = json["height"];
    iso6391 = json["iso_639_1"];
    filePath = json["file_path"];
    voteAverage = json["vote_average"];
    voteCount = json["vote_count"];
    width = json["width"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["aspect_ratio"] = aspectRatio;
    _data["height"] = height;
    _data["iso_639_1"] = iso6391;
    _data["file_path"] = filePath;
    _data["vote_average"] = voteAverage;
    _data["vote_count"] = voteCount;
    _data["width"] = width;
    return _data;
  }

  TheMovieImageLogos copyWith({
    num? aspectRatio,
    int? height,
    String? iso6391,
    String? filePath,
    num? voteAverage,
    int? voteCount,
    int? width,
  }) =>
      TheMovieImageLogos(
        aspectRatio: aspectRatio ?? this.aspectRatio,
        height: height ?? this.height,
        iso6391: iso6391 ?? this.iso6391,
        filePath: filePath ?? this.filePath,
        voteAverage: voteAverage ?? this.voteAverage,
        voteCount: voteCount ?? this.voteCount,
        width: width ?? this.width,
      );
}

class TheMovieImageBackdrops {
  num? aspectRatio;
  int? height;
  String? iso6391;
  String? filePath;
  num? voteAverage;
  int? voteCount;
  int? width;

  TheMovieImageBackdrops(
      {this.aspectRatio,
      this.height,
      this.iso6391,
      this.filePath,
      this.voteAverage,
      this.voteCount,
      this.width});

  TheMovieImageBackdrops.fromJson(Map<String, dynamic> json) {
    aspectRatio = json["aspect_ratio"];
    height = json["height"];
    iso6391 = json["iso_639_1"];
    filePath = json["file_path"];
    voteAverage = json["vote_average"];
    voteCount = json["vote_count"];
    width = json["width"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["aspect_ratio"] = aspectRatio;
    _data["height"] = height;
    _data["iso_639_1"] = iso6391;
    _data["file_path"] = filePath;
    _data["vote_average"] = voteAverage;
    _data["vote_count"] = voteCount;
    _data["width"] = width;
    return _data;
  }

  TheMovieImageBackdrops copyWith({
    num? aspectRatio,
    int? height,
    String? iso6391,
    String? filePath,
    num? voteAverage,
    int? voteCount,
    int? width,
  }) =>
      TheMovieImageBackdrops(
        aspectRatio: aspectRatio ?? this.aspectRatio,
        height: height ?? this.height,
        iso6391: iso6391 ?? this.iso6391,
        filePath: filePath ?? this.filePath,
        voteAverage: voteAverage ?? this.voteAverage,
        voteCount: voteCount ?? this.voteCount,
        width: width ?? this.width,
      );
}

==> _private_core_network-1.3.48.tar.gz: lib/network_resources/model/the_movie_photo.dart <==
class TheMovieImage {
  List<TheMovieImageBackdrops>? backdrops;
  int? id;
  List<TheMovieImageLogos>? logos;
  List<TheMovieImagePosters>? posters;

  TheMovieImage({this.backdrops, this.id, this.logos, this.posters});

  TheMovieImage.fromJson(Map<String, dynamic> json) {
    backdrops = json["backdrops"] == null
        ? null
        : (json["backdrops"] as List)
            .map((e) => TheMovieImageBackdrops.fromJson(e))
            .toList();
    id = json["id"];
    logos = json["logos"] == null
        ? null
        : (json["logos"] as List)
            .map((e) => TheMovieImageLogos.fromJson(e))
            .toList();
    posters = json["posters"] == null
        ? null
        : (json["posters"] as List)
            .map((e) => TheMovieImagePosters.fromJson(e))
            .toList();
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    if (backdrops != null) {
      data["backdrops"] = backdrops?.map((e) => e.toJson()).toList();
    }
    data["id"] = id;
    if (logos != null) {
      data["logos"] = logos?.map((e) => e.toJson()).toList();
    }
    if (posters != null) {
      data["posters"] = posters?.map((e) => e.toJson()).toList();
    }
    return data;
  }

  TheMovieImage copyWith({
    List<TheMovieImageBackdrops>? backdrops,
    int? id,
    List<TheMovieImageLogos>? logos,
    List<TheMovieImagePosters>? posters,
  }) =>
      TheMovieImage(
        backdrops: backdrops ?? this.backdrops,
        id: id ?? this.id,
        logos: logos ?? this.logos,
        posters: posters ?? this.posters,
      );
}

class TheMovieImagePosters {
  num? aspectRatio;
  int? height;
  String? iso6391;
  String? filePath;
  num? voteAverage;
  int? voteCount;
  int? width;

  TheMovieImagePosters(
      {this.aspectRatio,
      this.height,
      this.iso6391,
      this.filePath,
      this.voteAverage,
      this.voteCount,
      this.width});

  TheMovieImagePosters.fromJson(Map<String, dynamic> json) {
    aspectRatio = json["aspect_ratio"];
    height = json["height"];
    iso6391 = json["iso_639_1"];
    filePath = json["file_path"];
    voteAverage = json["vote_average"];
    voteCount = json["vote_count"];
    width = json["width"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["aspect_ratio"] = aspectRatio;
    data["height"] = height;
    data["iso_639_1"] = iso6391;
    data["file_path"] = filePath;
    data["vote_average"] = voteAverage;
    data["vote_count"] = voteCount;
    data["width"] = width;
    return data;
  }

  TheMovieImagePosters copyWith({
    num? aspectRatio,
    int? height,
    String? iso6391,
    String? filePath,
    num? voteAverage,
    int? voteCount,
    int? width,
  }) =>
      TheMovieImagePosters(
        aspectRatio: aspectRatio ?? this.aspectRatio,
        height: height ?? this.height,
        iso6391: iso6391 ?? this.iso6391,
        filePath: filePath ?? this.filePath,
        voteAverage: voteAverage ?? this.voteAverage,
        voteCount: voteCount ?? this.voteCount,
        width: width ?? this.width,
      );
}

class TheMovieImageLogos {
  num? aspectRatio;
  int? height;
  String? iso6391;
  String? filePath;
  num? voteAverage;
  int? voteCount;
  int? width;

  TheMovieImageLogos(
      {this.aspectRatio,
      this.height,
      this.iso6391,
      this.filePath,
      this.voteAverage,
      this.voteCount,
      this.width});

  TheMovieImageLogos.fromJson(Map<String, dynamic> json) {
    aspectRatio = json["aspect_ratio"];
    height = json["height"];
    iso6391 = json["iso_639_1"];
    filePath = json["file_path"];
    voteAverage = json["vote_average"];
    voteCount = json["vote_count"];
    width = json["width"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["aspect_ratio"] = aspectRatio;
    data["height"] = height;
    data["iso_639_1"] = iso6391;
    data["file_path"] = filePath;
    data["vote_average"] = voteAverage;
    data["vote_count"] = voteCount;
    data["width"] = width;
    return data;
  }

  TheMovieImageLogos copyWith({
    num? aspectRatio,
    int? height,
    String? iso6391,
    String? filePath,
    num? voteAverage,
    int? voteCount,
    int? width,
  }) =>
      TheMovieImageLogos(
        aspectRatio: aspectRatio ?? this.aspectRatio,
        height: height ?? this.height,
        iso6391: iso6391 ?? this.iso6391,
        filePath: filePath ?? this.filePath,
        voteAverage: voteAverage ?? this.voteAverage,
        voteCount: voteCount ?? this.voteCount,
        width: width ?? this.width,
      );
}

class TheMovieImageBackdrops {
  num? aspectRatio;
  int? height;
  String? iso6391;
  String? filePath;
  num? voteAverage;
  int? voteCount;
  int? width;

  TheMovieImageBackdrops(
      {this.aspectRatio,
      this.height,
      this.iso6391,
      this.filePath,
      this.voteAverage,
      this.voteCount,
      this.width});

  TheMovieImageBackdrops.fromJson(Map<String, dynamic> json) {
    aspectRatio = json["aspect_ratio"];
    height = json["height"];
    iso6391 = json["iso_639_1"];
    filePath = json["file_path"];
    voteAverage = json["vote_average"];
    voteCount = json["vote_count"];
    width = json["width"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["aspect_ratio"] = aspectRatio;
    data["height"] = height;
    data["iso_639_1"] = iso6391;
    data["file_path"] = filePath;
    data["vote_average"] = voteAverage;
    data["vote_count"] = voteCount;
    data["width"] = width;
    return data;
  }

  TheMovieImageBackdrops copyWith({
    num? aspectRatio,
    int? height,
    String? iso6391,
    String? filePath,
    num? voteAverage,
    int? voteCount,
    int? width,
  }) =>
      TheMovieImageBackdrops(
        aspectRatio: aspectRatio ?? this.aspectRatio,
        height: height ?? this.height,
        iso6391: iso6391 ?? this.iso6391,
        filePath: filePath ?? this.filePath,
        voteAverage: voteAverage ?? this.voteAverage,
        voteCount: voteCount ?? this.voteCount,
        width: width ?? this.width,
      );
}
